"""Logyca libraries, apiresult, health check dto"""

__version__ = "0.1.4a1"

from logyca.data.enums.healthenum import HealthEnum as HealthEnum
from logyca.data.enums.logycastatusenum import LogycaStatusEnum as LogycaStatusEnum

from logyca.data.schemas.dtos.apifilterexceptiondto import ApiFilterExceptionDTO as ApiFilterExceptionDTO
from logyca.data.schemas.dtos.apIresultdto import APIResultDTO as APIResultDTO
from logyca.data.schemas.dtos.healthdto import HealthDTO as HealthDTO
from logyca.data.schemas.dtos.httpexceptiondto import HTTPExceptionDTO as HTTPExceptionDTO
from logyca.data.schemas.dtos.tokensdto import TokensDTO as TokensDTO

from logyca.common.constants import Constants as Constants

from logyca.helpers.datetimehelpers import convertDateTimeStampUTCtoUTCColombia as convertDateTimeStampUTCtoUTCColombia
from logyca.helpers.stringshelpers import buildUrl as buildUrl







from datetime import datetime
import pytz
from logyca.common.constants import Constants

def convertDateTimeStampUTCtoUTCColombia(timestamp)->datetime:
    expUTC=datetime.utcfromtimestamp(timestamp)
    timezoneUTC = pytz.timezone(Constants.TimeZoneUTC)
    dateTimeUTC = timezoneUTC.localize(expUTC, is_dst=None)
    dateTimeColombia = dateTimeUTC.astimezone(pytz.timezone(Constants.TimeZoneColombia))
    return dateTimeColombia